from django.db import models
from django.utils.translation import gettext_lazy
from wagtail.admin.edit_handlers import (
    FieldPanel,
    HelpPanel,
    MultiFieldPanel,
    StreamFieldPanel,
)
from wagtail.core import blocks
from wagtail.core.fields import StreamField
from wagtail.core.models import Page
from wagtail.images.blocks import ImageChooserBlock
from wagtail.images.edit_handlers import ImageChooserPanel
from wagtailmetadata.models import MetadataPageMixin

from tuning import help


class PersonBlock(blocks.StructBlock):
    name = blocks.CharBlock(label="jméno")
    district = blocks.CharBlock(label="obvod")
    info = blocks.CharBlock(label="info o nominaci")
    phone = blocks.CharBlock(label="telefon", required=False)
    email = blocks.EmailBlock(label="email", required=False)
    web = blocks.URLBlock(label="web", required=False)
    photo = ImageChooserBlock(label="fotka")

    class Meta:
        icon = "person"
        label = "osoba"


class SenateHomePage(MetadataPageMixin, Page):
    ### FIELDS

    senators = StreamField(
        [("item", PersonBlock())], verbose_name="naši senátoři", blank=True
    )
    candidates = StreamField(
        [("item", PersonBlock())], verbose_name="kandidáti", blank=True
    )
    matomo_id = models.IntegerField(
        "Matomo ID pro sledování návštěvnosti", blank=True, null=True
    )

    ### PANELS

    content_panels = Page.content_panels + [
        StreamFieldPanel("senators"),
        StreamFieldPanel("candidates"),
    ]

    promote_panels = [
        MultiFieldPanel(
            [
                FieldPanel("seo_title"),
                FieldPanel("search_description"),
                ImageChooserPanel("search_image"),
                HelpPanel(help.build(help.IMPORTANT_TITLE)),
            ],
            gettext_lazy("Common page configuration"),
        ),
    ]

    settings_panels = [
        FieldPanel("matomo_id"),
    ]

    ### RELATIONS

    subpage_types = []

    ### OTHERS

    class Meta:
        verbose_name = "Senátní rozcestník"
